# mi_plugin_de_fechas

Este es un plugin de Python para convertir fechas basadas en códigos postales a la zona horaria correspondiente.

## Instalación

Puedes instalar este paquete usando `pip`:

```bash
pip install pluginFecha